@@ -13,7 +13,7 @@
 #'
 #' @export
 #'
-#' @import raster sp sf
+#' @import raster sf
 #'
 #' @examples
 #' shape  <- raster::shapefile(paste(system.file("extdata", package = "EmissV"),
@@ -24,12 +24,8 @@
 #' grid   <- gridInfo(paste(system.file("extdata", package = "EmissV"),"/wrfinput_d02",sep=""))
 #' SP     <- areaSource(shape,raster,grid,name = "SPMA")
 #' \donttest{
-#' sp::spplot(SP,scales = list(draw=TRUE),ylab="Lat",xlab="Lon",
-#'            main=list(label="Spatial Distribution by Lights for Sao Paulo - Brazil"),
-#'            col.regions = c("#031638","#001E48","#002756","#003062",
-#'                            "#003A6E","#004579","#005084","#005C8E",
-#'                            "#006897","#0074A1","#0081AA","#008FB3",
-#'                            "#009EBD","#00AFC8","#00C2D6","#00E3F0"))
+#' raster::plot(SP,ylab="Lat",xlab="Lon",
+#'              main ="Spatial Distribution by Lights for Sao Paulo - Brazil")
 #'}
 #'
 #'@source Data avaliable \url{https://www.ospo.noaa.gov/Operations/DMSP/index.html}
@@ -41,7 +37,8 @@ areaSource <- function(s,r,grid = NA,name = "",as_frac=FALSE,verbose = TRUE){
     cat(paste("processing ",name,"area ... \n",sep = ""))
   }
 
-  sp <- suppressWarnings( raster::mask(r,sp::spTransform(s,sp::CRS(sp::proj4string(r)))) )
+  # sp <- suppressWarnings( raster::mask(r,sp::spTransform(s,sp::CRS(sp::proj4string(r)))) )
+  sp <- suppressWarnings( raster::mask(r,sf::st_transform(sf::st_as_sf(s),crs = raster::crs(r,asText=TRUE))))
 
   if(!is.na(grid[1])){
     if(grid$map_proj == 1){
